@@ -1,8 +1,8 @@
-mod basic_conflict;
+mod all_branches;
 mod basic;
+mod basic_conflict;
 mod checked_out;
 mod conflict_resume;
-mod create_test_repo;
 mod multiple_branches;
 mod multiple_refs_on_branch;
 mod random;
